@@ -10,10 +10,7 @@ function smarty_function_banner($params, &$smarty)
 {
     global $tikilib;
     global $dbTiki;
-    include_once('lib/banners/bannerlib.php');
-    if(!isset($bannerlib)) {
-      $bannerlib = new BannerLib($dbTiki);
-    }
+    global $bannerlib;include_once('lib/banners/bannerlib.php');
 
     extract($params);
     // Param = zone
@@ -22,10 +19,14 @@ function smarty_function_banner($params, &$smarty)
         $smarty->trigger_error("assign: missing 'zone' parameter");
         return;
     }
-    $banner = $bannerlib->select_banner($zone);
+	if (empty($target)) {
+		$banner = $bannerlib->select_banner($zone);
+	} else {
+		$banner = $bannerlib->select_banner($zone, $target);
+	}
     print($banner);
 }
 
-/* vim: set expandtab: */
+
 
 ?>
